==> smartgwt-4.0p.zip: com/smartgwt/client/docs/Images.java <==

package com.smartgwt.client.docs;

/**
 * Referring to and loading images. <P> The two main URL settings relevant to loading images
 * are:<br> * imgDir (where application-specific images live)<br> * skinImgDir (where system
 * supplied images live)<br>
 * @see com.smartgwt.client.widgets.Canvas#getImgURL
 * @see com.smartgwt.client.widgets.Canvas#imgHTML
 * @see com.smartgwt.client.widgets.Canvas#getImage
 * @see com.smartgwt.client.widgets.Canvas#setImage
 * @see com.smartgwt.client.util.Page#setAppImgDir
 * @see com.smartgwt.client.util.Page#getAppImgDir
 * @see com.smartgwt.client.util.Page#setAppFilesDir
 * @see com.smartgwt.client.util.Page#getAppFilesDir
 * @see com.smartgwt.client.util.Page#setSkinDir
 * @see com.smartgwt.client.util.Page#getSkinDir
 * @see com.smartgwt.client.util.Page#getSkinImgDir
 * @see com.smartgwt.client.util.Page#getImgURL
 * @see com.smartgwt.client.util.Page#getURL
 * @see com.smartgwt.client.util.Page#loadStyleSheet
 * @see com.smartgwt.client.widgets.tab.TabSet#getSkinImgDir
 * @see com.smartgwt.client.widgets.grid.ListGrid#getSkinImgDir
 * @see com.smartgwt.client.widgets.Canvas#getAppImgDir
 * @see com.smartgwt.client.widgets.Canvas#getSkinImgDir
 * @see com.smartgwt.client.widgets.cube.CubeGrid#getSkinImgDir
 * @see com.smartgwt.client.widgets.Scrollbar#getSkinImgDir
 * @see com.smartgwt.client.widgets.Scrollbar#getCornerSrc
 * @see com.smartgwt.client.widgets.Scrollbar#getHSrc
 * @see com.smartgwt.client.widgets.Scrollbar#getVSrc
 * @see com.smartgwt.client.widgets.Splitbar#getSkinImgDir
 * @see com.smartgwt.client.widgets.ImgSplitbar#getSkinImgDir
 */
public interface Images {
}

==> smartgwt-6.1p.zip: com/smartgwt/client/docs/Images.java <==

package com.smartgwt.client.docs;

/**
 * Referring to and loading images. <P> The two main URL settings relevant to loading images
 * are:<br> * imgDir (where application-specific images live)<br> * skinImgDir (where system
 * supplied images live)<br>
 * @see com.smartgwt.client.util.Page#setAppImgDir
 * @see com.smartgwt.client.util.Page#getAppImgDir
 * @see com.smartgwt.client.util.Page#setAppFilesDir
 * @see com.smartgwt.client.util.Page#getAppFilesDir
 * @see com.smartgwt.client.util.Page#setSkinDir
 * @see com.smartgwt.client.util.Page#getSkinDir
 * @see com.smartgwt.client.util.Page#getSkinImgDir
 * @see com.smartgwt.client.util.Page#getImgURL
 * @see com.smartgwt.client.util.Page#getURL
 * @see com.smartgwt.client.util.Page#loadStyleSheet
 * @see com.smartgwt.client.widgets.Canvas#imgHTML
 * @see com.smartgwt.client.widgets.Canvas#getImgURL
 * @see com.smartgwt.client.widgets.Canvas#imgHTML
 * @see com.smartgwt.client.widgets.Canvas#getImage
 * @see com.smartgwt.client.widgets.Canvas#setImage
 * @see com.smartgwt.client.widgets.cube.CubeGrid#getSkinImgDir
 * @see com.smartgwt.client.widgets.Canvas#getAppImgDir
 * @see com.smartgwt.client.widgets.Canvas#getSkinImgDir
 * @see com.smartgwt.client.widgets.Canvas#getUseImageForSVG
 * @see com.smartgwt.client.widgets.tab.TabSet#getSkinImgDir
 * @see com.smartgwt.client.widgets.form.fields.FileItem#getViewIconSrc
 * @see com.smartgwt.client.widgets.form.fields.FileItem#getDownloadIconSrc
 * @see com.smartgwt.client.widgets.Scrollbar#getSkinImgDir
 * @see com.smartgwt.client.widgets.Scrollbar#getCornerSrc
 * @see com.smartgwt.client.widgets.Scrollbar#getHSrc
 * @see com.smartgwt.client.widgets.Scrollbar#getVSrc
 * @see com.smartgwt.client.widgets.Splitbar#getSkinImgDir
 * @see com.smartgwt.client.widgets.ImgSplitbar#getSkinImgDir
 * @see com.smartgwt.client.widgets.grid.ListGrid#getSkinImgDir
 */
public interface Images {
}
